@@ -1,4 +1,4 @@
 from draw_polygon import draw_polygon  # noqa
 from find_contours import find_contours  # noqa
 from simplify_polygon import simplify_polygon  # noqa
-from rle import rle_decode, rle_encode # noqa
+from run_length_encoding import rle_decode, rle_encode  # noqa
